@@ -1834,7 +1834,7 @@ class GeoTimeClassify:
                         else:
                             month_day_results.append("failed")
                     else:
-                        loggin.warn("Month_day test: Not a valid digit")
+                        logging.warning("Month_day test: Not a valid digit")
                 except Exception as e:
                     logging.error(f"month_day_f - {md}: {e}")
 
@@ -2098,7 +2098,7 @@ class GeoTimeClassify:
                 else:
                     pred2['fuzzyColumn']=pred2['fuzzyColumn'][0]
             except Exception as e:
-                logging.warn(pred2['column'], f"fuzzymatchColumns - Column has no fuzzy match: {e}")
+                logging.warning(pred2['column'], f"fuzzymatchColumns - Column has no fuzzy match: {e}")
 
 
         return predictions
